wallaroo.wallaroo_ml_ops_api_client.models.pipelines_create_response_200 API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.pipelines_create_response_200

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5T = TypeVar("T", bound="PipelinesCreateResponse200")
     6
     7@attr.s(auto_attribs=True)
     8class PipelinesCreateResponse200:
     9    """ Successful response to pipeline creation request.
    10
    11    Attributes:
    12        pipeline_pk_id (int):  Internal pipeline identifier.
    13        pipeline_variant_pk_id (int):  Internal pipeline variant identifier.
    14        pipeline_variant_version (str):  Pipeline Version UUID identifier
    15    """
    16
    17    pipeline_pk_id: int
    18    pipeline_variant_pk_id: int
    19    pipeline_variant_version: str
    20    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    21
    22
    23    def to_dict(self) -> Dict[str, Any]:
    24        pipeline_pk_id = self.pipeline_pk_id
    25        pipeline_variant_pk_id = self.pipeline_variant_pk_id
    26        pipeline_variant_version = self.pipeline_variant_version
    27
    28        field_dict: Dict[str, Any] = {}
    29        field_dict.update(self.additional_properties)
    30        field_dict.update({
    31            "pipeline_pk_id": pipeline_pk_id,
    32            "pipeline_variant_pk_id": pipeline_variant_pk_id,
    33            "pipeline_variant_version": pipeline_variant_version,
    34        })
    35
    36        return field_dict
    37
    38
    39
    40    @classmethod
    41    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    42        d = src_dict.copy()
    43        pipeline_pk_id = d.pop("pipeline_pk_id")
    44
    45        pipeline_variant_pk_id = d.pop("pipeline_variant_pk_id")
    46
    47        pipeline_variant_version = d.pop("pipeline_variant_version")
    48
    49        pipelines_create_response_200 = cls(
    50            pipeline_pk_id=pipeline_pk_id,
    51            pipeline_variant_pk_id=pipeline_variant_pk_id,
    52            pipeline_variant_version=pipeline_variant_version,
    53        )
    54
    55        pipelines_create_response_200.additional_properties = d
    56        return pipelines_create_response_200
    57
    58    @property
    59    def additional_keys(self) -> List[str]:
    60        return list(self.additional_properties.keys())
    61
    62    def __getitem__(self, key: str) -> Any:
    63        return self.additional_properties[key]
    64
    65    def __setitem__(self, key: str, value: Any) -> None:
    66        self.additional_properties[key] = value
    67
    68    def __delitem__(self, key: str) -> None:
    69        del self.additional_properties[key]
    70
    71    def __contains__(self, key: str) -> bool:
    72        return key in self.additional_properties

@attr.s(auto_attribs=True)
class PipelinesCreateResponse200: View Source

     8@attr.s(auto_attribs=True)
     9class PipelinesCreateResponse200:
    10    """ Successful response to pipeline creation request.
    11
    12    Attributes:
    13        pipeline_pk_id (int):  Internal pipeline identifier.
    14        pipeline_variant_pk_id (int):  Internal pipeline variant identifier.
    15        pipeline_variant_version (str):  Pipeline Version UUID identifier
    16    """
    17
    18    pipeline_pk_id: int
    19    pipeline_variant_pk_id: int
    20    pipeline_variant_version: str
    21    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    22
    23
    24    def to_dict(self) -> Dict[str, Any]:
    25        pipeline_pk_id = self.pipeline_pk_id
    26        pipeline_variant_pk_id = self.pipeline_variant_pk_id
    27        pipeline_variant_version = self.pipeline_variant_version
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "pipeline_pk_id": pipeline_pk_id,
    33            "pipeline_variant_pk_id": pipeline_variant_pk_id,
    34            "pipeline_variant_version": pipeline_variant_version,
    35        })
    36
    37        return field_dict
    38
    39
    40
    41    @classmethod
    42    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    43        d = src_dict.copy()
    44        pipeline_pk_id = d.pop("pipeline_pk_id")
    45
    46        pipeline_variant_pk_id = d.pop("pipeline_variant_pk_id")
    47
    48        pipeline_variant_version = d.pop("pipeline_variant_version")
    49
    50        pipelines_create_response_200 = cls(
    51            pipeline_pk_id=pipeline_pk_id,
    52            pipeline_variant_pk_id=pipeline_variant_pk_id,
    53            pipeline_variant_version=pipeline_variant_version,
    54        )
    55
    56        pipelines_create_response_200.additional_properties = d
    57        return pipelines_create_response_200
    58
    59    @property
    60    def additional_keys(self) -> List[str]:
    61        return list(self.additional_properties.keys())
    62
    63    def __getitem__(self, key: str) -> Any:
    64        return self.additional_properties[key]
    65
    66    def __setitem__(self, key: str, value: Any) -> None:
    67        self.additional_properties[key] = value
    68
    69    def __delitem__(self, key: str) -> None:
    70        del self.additional_properties[key]
    71
    72    def __contains__(self, key: str) -> bool:
    73        return key in self.additional_properties

Successful response to pipeline creation request.

Attributes: pipeline_pk_id (int): Internal pipeline identifier. pipeline_variant_pk_id (int): Internal pipeline variant identifier. pipeline_variant_version (str): Pipeline Version UUID identifier

PipelinesCreateResponse200( pipeline_pk_id: int, pipeline_variant_pk_id: int, pipeline_variant_version: str) View Source

    2def __init__(self, pipeline_pk_id, pipeline_variant_pk_id, pipeline_variant_version):
    3    self.pipeline_pk_id = pipeline_pk_id
    4    self.pipeline_variant_pk_id = pipeline_variant_pk_id
    5    self.pipeline_variant_version = pipeline_variant_version
    6    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class PipelinesCreateResponse200.

def to_dict(self) -> Dict[str, Any]: View Source

    24    def to_dict(self) -> Dict[str, Any]:
    25        pipeline_pk_id = self.pipeline_pk_id
    26        pipeline_variant_pk_id = self.pipeline_variant_pk_id
    27        pipeline_variant_version = self.pipeline_variant_version
    28
    29        field_dict: Dict[str, Any] = {}
    30        field_dict.update(self.additional_properties)
    31        field_dict.update({
    32            "pipeline_pk_id": pipeline_pk_id,
    33            "pipeline_variant_pk_id": pipeline_variant_pk_id,
    34            "pipeline_variant_version": pipeline_variant_version,
    35        })
    36
    37        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    41    @classmethod
    42    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    43        d = src_dict.copy()
    44        pipeline_pk_id = d.pop("pipeline_pk_id")
    45
    46        pipeline_variant_pk_id = d.pop("pipeline_variant_pk_id")
    47
    48        pipeline_variant_version = d.pop("pipeline_variant_version")
    49
    50        pipelines_create_response_200 = cls(
    51            pipeline_pk_id=pipeline_pk_id,
    52            pipeline_variant_pk_id=pipeline_variant_pk_id,
    53            pipeline_variant_version=pipeline_variant_version,
    54        )
    55
    56        pipelines_create_response_200.additional_properties = d
    57        return pipelines_create_response_200

additional_keys: List[str]